<?php

namespace Drupal\sfc;

use Drupal\Component\Plugin\PluginManagerInterface;
use Twig\Error\LoaderError;
use Twig\Loader\ExistsLoaderInterface;
use Twig\Loader\LoaderInterface;

/**
 * Loads a template from a Single File Component.
 */
class TwigComponentLoader implements LoaderInterface, ExistsLoaderInterface {

  /**
   * The plugin manager.
   *
   * @var \Drupal\Component\Plugin\PluginManagerInterface
   */
  protected $manager;

  /**
   * TwigComponentLoader constructor.
   *
   * @param \Drupal\Component\Plugin\PluginManagerInterface $manager
   *   The plugin manager.
   */
  public function __construct(PluginManagerInterface $manager) {
    $this->manager = $manager;
  }

  /**
   * {@inheritdoc}
   */
  public function getSource($name) {
    return $this->getTemplate($name);
  }

  /**
   * {@inheritdoc}
   */
  public function exists($name) {
    return (bool) $this->getTemplate($name);
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheKey($name) {
    if (!($template = $this->getTemplate($name))) {
      throw new LoaderError(sprintf('Template "%s" is not defined.', $name));
    }

    return $name . ':' . $template;
  }

  /**
   * {@inheritdoc}
   */
  public function isFresh($name, $time) {
    if (!$this->getTemplate($name)) {
      throw new LoaderError(sprintf('Template "%s" is not defined.', $name));
    }

    return TRUE;
  }

  /**
   * Gets the template string from the single file component class.
   *
   * @param string $name
   *   The template name.
   *
   * @return bool|string
   *   The template, or FALSE if this is not a single file component.
   */
  protected function getTemplate($name) {
    if (!ComponentNameHelper::isComponentTemplate($name)) {
      return FALSE;
    }
    $id = ComponentNameHelper::getIdFromTemplateName($name);
    $component = $this->manager->createInstance($id);
    return $component->getTemplate();
  }

}
